@@ -1,8 +1,8 @@
 package Net::Twitter;
-$Net::Twitter::VERSION = '4.01010';
+$Net::Twitter::VERSION = '4.01020';
 use Moose;
 use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
-use JSON;
+use JSON::MaybeXS;
 use Net::Twitter::Core;
 use Digest::SHA qw/sha1_hex/;
 use Class::Load ();
@@ -160,7 +160,7 @@ Net::Twitter - A perl interface to the Twitter API
 
 =head1 VERSION
 
-version 4.01010
+version 4.01020
 
 =head1 DESCRIPTION
 
