@@ -1,5 +1,5 @@
 package Net::Twitter::API;
-$Net::Twitter::API::VERSION = '4.01010';
+$Net::Twitter::API::VERSION = '4.01020';
 use Moose ();
 use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
 use Moose::Exporter;
@@ -99,6 +99,7 @@ sub twitter_api_method {
             $args,
             $authenticate,
             $options{datetime_parser},
+            $options{content_type}
         );
     };
 
@@ -116,7 +117,7 @@ sub twitter_api_method {
 }
 
 package Net::Twitter::Meta::Method;
-$Net::Twitter::Meta::Method::VERSION = '4.01010';
+$Net::Twitter::Meta::Method::VERSION = '4.01020';
 use Moose;
 use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
 extends 'Moose::Meta::Method';
@@ -137,6 +138,7 @@ has authenticate    => ( isa => 'Bool', is => 'ro', required => 1 );
 has datetime_parser => ( is => 'ro', required => 1 );
 has base_url_method => ( isa => 'Str', is => 'ro', required => 1 );
 has path_suffix     => ( isa => 'Str', is => 'ro', required => 1 );
+has content_type     => ( isa => 'Str', is => 'ro', default => '' );
 
 # TODO: can MooseX::StrictConstructor be made to work here?
 my %valid_attribute_names = map { $_->init_arg => 1 }
@@ -162,7 +164,7 @@ Net::Twitter::API - Moose sugar for defining Twitter API methods
 
 =head1 VERSION
 
-version 4.01010
+version 4.01020
 
 =head1 SYNOPSIS
 
@@ -280,7 +282,7 @@ Marc Mims <marc@questright.com>
 
 =head1 LICENSE
 
-Copyright (c) 2009 Marc Mims
+Copyright (c) 2016 Marc Mims
 
 The Twitter API itself, and the description text used in this module is:
 
