@@ -1,11 +1,11 @@
 package Net::Twitter::Core;
-$Net::Twitter::Core::VERSION = '4.01010';
+$Net::Twitter::Core::VERSION = '4.01020';
 # ABSTRACT: A perl interface to the Twitter API
 
 use 5.008001;
 use Moose;
 use Carp::Clan qw/^(?:Net::Twitter|Moose|Class::MOP)/;
-use JSON;
+use JSON::MaybeXS;
 use URI::Escape;
 use HTTP::Request::Common;
 use Net::Twitter::Error;
@@ -36,7 +36,7 @@ has clienturl       => ( isa => 'Str', is => 'ro', default => 'http://search.cpa
 has _base_url       => ( is => 'rw' ); ### keeps role composition from bitching ??
 has _json_handler   => (
     is      => 'rw',
-    default => sub { JSON->new->utf8 },
+    default => sub { JSON->new->allow_nonref->utf8 },
     handles => { from_json => 'decode' },
 );
 
@@ -150,16 +150,16 @@ sub _encode_args {
 }
 
 sub _json_request {
-    my ($self, $http_method, $uri, $args, $authenticate, $dt_parser) = @_;
+    my ($self, $http_method, $uri, $args, $authenticate, $dt_parser, $content_type ) = @_;
 
-    my $msg = $self->_prepare_request($http_method, $uri, $args, $authenticate);
+    my $msg = $self->_prepare_request($http_method, $uri, $args, $authenticate, $content_type);
     my $res = $self->_send_request($msg);
 
     return $self->_parse_result($res, $args, $dt_parser);
 }
 
 sub _prepare_request {
-    my ($self, $http_method, $uri, $args, $authenticate) = @_;
+    my ($self, $http_method, $uri, $args, $authenticate, $content_type ) = @_;
 
     my $msg;
 
@@ -177,16 +177,21 @@ sub _prepare_request {
         $msg = HTTP::Request->new($http_method, $uri);
     }
     elsif ( $http_method eq 'POST' ) {
-        # if any of the arguments are (array) refs, use form-data
-        $msg = (first { ref } values %natural_args)
-             ? POST($uri,
-                    Content_Type => 'form-data',
-                    Content      => [
-                        map { ref $_ ? $_ : encode_utf8 $_ } %natural_args,
-                    ],
-               )
-             : POST($uri, Content => $self->_query_string_for(\%natural_args))
-             ;
+        if( $content_type && $content_type eq 'application/json' ) {
+            $msg = POST( $uri,  Content_Type => 'application/json', Content =>  encode_json \%natural_args );
+        }
+        else {
+            # if any of the arguments are (array) refs, use form-data
+            $msg = (first { ref } values %natural_args)
+                ? POST($uri,
+                       Content_Type => 'form-data',
+                       Content      => [
+                           map { ref $_ ? $_ : encode_utf8 $_ } %natural_args,
+                       ],
+                )
+                : POST($uri, Content => $self->_query_string_for(\%natural_args))
+                ;
+        }
     }
     else {
         croak "unexpected HTTP method: $http_method";
@@ -248,7 +253,7 @@ sub _parse_result {
     my $content = $res->content;
     $content =~ s/^"(true|false)"$/$1/;
 
-    my $obj = try { $self->from_json($content) };
+    my $obj = length $content ? try { $self->from_json($content) } : {};
     $self->_decode_html_entities($obj) if $obj && $self->decode_html_entities;
 
     # filter before inflating objects
@@ -353,7 +358,7 @@ Net::Twitter::Core - Net::Twitter implementation
 
 =head1 VERSION
 
-version 4.01010
+version 4.01020
 
 =head1 SYNOPSIS
 
@@ -375,7 +380,7 @@ Marc Mims <marc@questright.com>
 
 =head1 LICENSE
 
-Copyright (c) 2009 Marc Mims
+Copyright (c) 2016 Marc Mims
 
 The Twitter API itself, and the description text used in this module is:
 
